@@ -133,6 +133,7 @@ def __modules(attrs, src):
 
     if 'py_modules' in attrs:
         for mod in attrs['py_modules']:
+            print mod
             src_markglob(src, os.path.join(mod, '*.py'))
         return
 
@@ -379,6 +380,8 @@ def __requires(attrs, src_all):
 
     # iterate over all *.py and scripts which are Python
     for s in src_all:
+        if s == 'setup.py':
+            continue
         if s.startswith('data' + os.path.sep):
             continue
         ext = os.path.splitext(s)[1]
