@@ -2,13 +2,17 @@
 
 # test DistUtilsExtra.auto
 
-import sys, unittest, shutil, tempfile, os, os.path, subprocess, re
+import unittest, shutil, tempfile, os, os.path, subprocess, re
 
 class T(unittest.TestCase):
     def setUp(self):
         self.src = tempfile.mkdtemp()
 
         self._mksrc('setup.py', '''
+# ignore warning about import from local path
+import warnings
+warnings.filterwarnings('ignore', 'Module DistUtilsExtra was already imported from.*')
+
 from DistUtilsExtra.auto import setup
 
 setup(
@@ -28,7 +32,7 @@ setup(
         try:
             # check that setup.py clean removes everything
             (o, e, s) = self.setup_py(['clean', '-a'])
-            self.assertEqual(s, 0)
+            self.assertEqual(s, 0, o+e)
             cruft = self.diff_snapshot()
             self.assertEqual(cruft, '', 'no cruft after cleaning:\n' + cruft)
         finally:
@@ -707,7 +711,7 @@ print ('import iamnota.module')
 
         # check requires
         req = [prop.split(' ', 1)[1] for prop in egg if prop.startswith('Requires: ')]
-        self.assertEqual(set(req), set(['DistUtilsExtra.auto', 'httplib2', 'pkg_resources']))
+        self.assertEqual(set(req), set(['httplib2', 'pkg_resources']))
 
     def test_help(self):
         '''Docbook XML help'''
@@ -755,9 +759,11 @@ print ('import iamnota.module')
         if not self.snapshot:
             self.do_snapshot()
 
-        env = os.environ
+        env = os.environ.copy()
         oldcwd = os.getcwd()
-        if 'PYTHONPATH' not in env:
+        if 'PYTHONPATH' in env:
+            env['PYTHONPATH'] = oldcwd + os.pathsep + env['PYTHONPATH']
+        else:
             env['PYTHONPATH'] = oldcwd
         os.chdir(self.src)
         s = subprocess.Popen(['/proc/self/exe', 'setup.py'] + args, env=env,
